package com.jkcredit.info.query.controller;

import com.alibaba.fastjson.JSONObject;
import com.jkcredit.common.model.CommonResponseObject;
import com.jkcredit.info.query.service.InformationQueryService;
import com.jkcredit.info.query.util.SSLSocketClient;
import lombok.extern.slf4j.Slf4j;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.client.discovery.DiscoveryClient;
import org.springframework.cloud.client.loadbalancer.LoadBalancerClient;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.concurrent.TimeUnit;

@RestController
@Slf4j
public class InfoQueryController {
    @Value("${supplier.hostUrl}")
    private String hostUrl;

    @Autowired
    InformationQueryService informationQueryService;

    @Autowired
    LoadBalancerClient loadBalancerClient;
    @Autowired
    DiscoveryClient discoveryClient;

    @PostMapping("/query")
    public CommonResponseObject infoQuery(@RequestBody JSONObject body) {
        return informationQueryService.query(body.getString("keyWord"), body.getString("type"));
    }

    @PostMapping("/queryInfoList")
    public CommonResponseObject getInfoList(@RequestBody JSONObject body) {
        return informationQueryService.queryList(body.getString("keyWord"), body.getString("type"));
    }

    @PostMapping("/queryInfoDetail")
    public CommonResponseObject queryDetail(@RequestBody JSONObject body) {
        return informationQueryService.queryDetail(body.getString("path"));
    }

    @GetMapping(value = "/getImage", produces = {MediaType.IMAGE_JPEG_VALUE, MediaType.IMAGE_PNG_VALUE})
    public BufferedImage getImage(String exportType, String gmsfhm) {
        StringBuffer urlStringBuffer = new StringBuffer(hostUrl);
        urlStringBuffer.append("photoSearch/singlePhotoSearch.action?exportType=").append(exportType);
        urlStringBuffer.append("&gmsfhm=").append(gmsfhm);
        String imageUrl = urlStringBuffer.toString();
        log.info("getImage.imageUrl:{}", imageUrl);

        InputStream imageStream = informationQueryService.getImageStream(imageUrl);
        if (imageStream == null) {
            log.info("imageStream == null");
            return null;
        }
        try {
            return ImageIO.read(imageStream);
        } catch (Exception e) {
            log.error("getImage.url:{},Exception:{}", urlStringBuffer.toString(), e);
        }
        log.info("imageStream != null");

        return null;
    }

    // ../crjPhotoSearch/singlePhotoSearch.action?exportType=img&zjhm=C21368872&csdgj=中国&jgmc=河南省荥阳市
    @GetMapping(value = "/getCrjImage", produces = {MediaType.IMAGE_JPEG_VALUE, MediaType.IMAGE_PNG_VALUE})
    public BufferedImage getCrjImage(String exportType, String zjhm, String csdgj, String jgmc) {
        StringBuffer urlStringBuffer = new StringBuffer(hostUrl);
        urlStringBuffer.append("crjPhotoSearch/singlePhotoSearch.action?exportType=").append(exportType);
        urlStringBuffer.append("&zjhm=").append(zjhm);
        urlStringBuffer.append("&csdgj=").append(csdgj);
        urlStringBuffer.append("&jgmc=").append(jgmc);
        String imageUrl = urlStringBuffer.toString();
        log.info("getCrjImage.imageUrl:{}", imageUrl);

        InputStream imageStream = informationQueryService.getImageStream(imageUrl);
        if (imageStream == null) {
            return null;
        }
        try {
            return ImageIO.read(imageStream);
        } catch (Exception e) {
            log.error("getImage.url:{},Exception:{}", urlStringBuffer.toString(), e);
        }
        return null;
    }


    @PostMapping("/loadCookie")
    public CommonResponseObject loadCookie() {
        return informationQueryService.loadCookie();
    }

    @PostMapping("/getNewCookie")
    public CommonResponseObject getNewCookie() {
        return informationQueryService.getNewCookie();
    }

    @PostMapping("/test")
    public String test() {
        System.out.println(123);
        return "28081";
    }
}
