package com.jkcredit.info.query.task;

import com.jkcredit.info.query.util.CookieTaskConcurrentHashMapUtil;
import com.jkcredit.info.query.util.CookieUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import java.util.Random;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Slf4j
@Component
public class LoadCookieTask {
    @Scheduled(cron = "0 0/3 * * * ?", zone = "Asia/Shanghai")
    public void loadCookie() {
        long baseTime = 1080000;
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map<String, Long> cookieTaskMap = CookieTaskConcurrentHashMapUtil.getInstance();
        if (cookieTaskMap.size() == 0) {
            String cookie = CookieUtil.getNewCookie();
            if (StringUtils.isNotBlank(cookie)) {
                int randomNum = new Random().nextInt(600000);
                CookieTaskConcurrentHashMapUtil.getInstance().put("cookie", System.currentTimeMillis() + baseTime + randomNum);
                log.info("LoadCookieTask.LoadCookie:{}", simpleDateFormat.format(new Date(System.currentTimeMillis() + baseTime + randomNum)));
            }
        } else {
            long cookieTime = CookieTaskConcurrentHashMapUtil.getInstance().get("cookie");
            long nowTime = System.currentTimeMillis();
            if (cookieTime - nowTime <= 180000) {
                // 立即执行
                String cookie = CookieUtil.getNewCookie();
                if (StringUtils.isNotBlank(cookie)) {
                    int randomNum = new Random().nextInt(600000);
                    CookieTaskConcurrentHashMapUtil.getInstance().put("cookie", System.currentTimeMillis() + baseTime + randomNum);
                    log.info("LoadCookieTask.LoadCookie:{}", simpleDateFormat.format(new Date(System.currentTimeMillis() + baseTime + randomNum)));
                } else {
                    CookieTaskConcurrentHashMapUtil.clear();
                }
            }
        }
    }
}
