package com.jkcredit.info.query.util;

import com.jkcredit.info.query.constant.CommonConstant;
import lombok.extern.slf4j.Slf4j;
import okhttp3.*;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.TimeUnit;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Slf4j
public class HttpUtil {
    private static OkHttpClient okHttpClient = new OkHttpClient.Builder().build();

    public static String doPost(String url, FormBody formBody, String cookie) {
        Request okRequest = new Request.Builder()
                .post(formBody)
                .url(url)
                .header("Cookie", cookie)
                .build();
        OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(3000, TimeUnit.MILLISECONDS)
                .readTimeout(6000, TimeUnit.MILLISECONDS)
                .writeTimeout(6000, TimeUnit.MILLISECONDS)
                .sslSocketFactory(SSLSocketClient.getSocketFactory(), SSLSocketClient.getX509TrustManager())
                .hostnameVerifier(SSLSocketClient.getHostnameVerifier())
                .build();
        String responseContext = "";
        try {
            Response response = client.newCall(okRequest).execute();
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            response.close();
        } catch (IOException ioe) {
            log.error("doPost.IOException:", ioe);
        } catch (Exception e) {
            log.error("doPost.Exception:", e);
        }
        return responseContext;
    }

    public static String doGet(String url, String cookie) {
        Request okRequest = new Request.Builder().url(url)
                .header("Cookie", cookie)
                .build();

        OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(3000, TimeUnit.MILLISECONDS)
                .readTimeout(6000, TimeUnit.MILLISECONDS)
                .writeTimeout(6000, TimeUnit.MILLISECONDS)
                .sslSocketFactory(SSLSocketClient.getSocketFactory(), SSLSocketClient.getX509TrustManager())
                .hostnameVerifier(SSLSocketClient.getHostnameVerifier())
                .build();
        String responseContext = "";
        try {
            Response response = client.newCall(okRequest).execute();
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            response.close();
        } catch (IOException ioe) {
            log.error("doGet.IOException:", ioe);
        } catch (Exception e) {
            log.error("doGet.Exception:", e);
        }
        return responseContext;
    }

    public static String doGetLoadCookie(String url) {
        ConcurrentHashMap<String, List<Cookie>> cookieStore = CookieConcurrentHashMapUtil.getInstance();
        Request okRequest = new Request.Builder().url(url)
                .build();

        OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(3000, TimeUnit.MILLISECONDS)
                .readTimeout(6000, TimeUnit.MILLISECONDS)
                .writeTimeout(6000, TimeUnit.MILLISECONDS)
                .cookieJar(new CookieJar() {
                    @Override
                    public void saveFromResponse(HttpUrl httpUrl, List<Cookie> list) {
                        cookieStore.put(CommonConstant.COOKIE, list);
                    }

                    @Override
                    public List<Cookie> loadForRequest(HttpUrl httpUrl) {
                        List<Cookie> cookies = cookieStore.get(CommonConstant.COOKIE);
                        return cookies != null ? cookies : new ArrayList<Cookie>();
                    }
                })
                .sslSocketFactory(SSLSocketClient.getSocketFactory(), SSLSocketClient.getX509TrustManager())
                .hostnameVerifier(SSLSocketClient.getHostnameVerifier())
                .build();
        String responseContext = "";
        try {
            Response response = client.newCall(okRequest).execute();
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            response.close();
        } catch (IOException ioe) {
            log.error("doGetLoadCookie.IOException:", ioe);
        } catch (Exception e) {
            log.error("doGetLoadCookie.Exception:", e);
        }
        return responseContext;
    }

    public static InputStream doGetStream(String url, String cookie) {
        Request okRequest = new Request.Builder().url(url)
                .header("Cookie", cookie)
                .build();

        OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(3000, TimeUnit.MILLISECONDS)
                .readTimeout(6000, TimeUnit.MILLISECONDS)
                .writeTimeout(6000, TimeUnit.MILLISECONDS)
                .sslSocketFactory(SSLSocketClient.getSocketFactory(), SSLSocketClient.getX509TrustManager())
                .hostnameVerifier(SSLSocketClient.getHostnameVerifier())
                .build();
        InputStream responseStream = null;

        try {
            Response response = client.newCall(okRequest).execute();
            if (response.body() != null) {
                responseStream =  new ByteArrayInputStream(response.body().bytes());
            }
            response.close();
        } catch (IOException ioe) {
            log.error("doGetStream.IOException:", ioe);
        } catch (Exception e) {
            log.error("doGetStream.Exception:", e);
        }
        return responseStream;
    }

    public static void main(String[] args) {
        System.setProperty("https.proxyHost", "127.0.0.1");
        System.setProperty("https.proxyPort", "9986");

        String cookie = CookieUtil.getAuthenticationCookie();

        FormBody formBody = new FormBody.Builder()
                .add("pinyin", "false")
                .add("keyWord", "110223199507101866")
                .build();
        System.out.println(doPost("https://jwzhcx.ga/cloudSearch/goSearch.action", formBody, cookie));
//        System.out.println(doGet("https://jwzhcx.ga/cloudSearch/ajaxQueryResult.action?pinyin=false&keyWord=%E4%BA%ACAQB470&reportQuery.id=5edb64d0f73f233bf99165c6&resource.id=5ee493d5f73f23422e32031c", cookie));
        System.out.println(123);
    }
}
